---
layout: post
title: "Academia as a Gift Economy"
description: "How a shared misunderstanding of public goods provision leads to academic discontent."
tags:
 - academia
 - gift economy
 - public goods
 - publishing
 - software
---

I recently got a sense from some Twitter posts about me that I may be seen by others in political science as a notable "public goods" provider. This is in reference to my [software](https://github.com/leeper/) and [teaching materials](https://www.thomasleeper.com/teaching.html), which I for the most part make freely available with open-source licenses. The discussion got me thinking about the meaning of "public goods" in academic work and how we collectively understand the provision of such goods.

A simplistic model of academic work is that universities (and sometimes other organizations) pay academics to produce "public goods" (like research) and then individually reward academics for their production of certain "public goods" through systems of promotion, salary, and tenure. That these systems of individual reward only - or primarily - incentivize some activities (namely, the production of peer-reviewed articles in a subset of academic journals) and do not reward other things (like [emotional labor](http://www.jstor.org/stable/1049284)) raise questions both about what individual academics should spend their time doing and what kinds of incentive structures should be in place in light of the need for "public goods" that are not presently incentivized. These discussions frequently emphasize gender disparities - as well as age, rank, racial, ethnic, etc. disparities - in expectations about public good provision. As such, it seems that the disconnect between demand for "public goods" and the incentives to produce them are both out-of-sync but also felt unevenly across individuals within academia.

An answer to these problems that I have frequently turned to is the idea that "public goods" provision should be better incentivized. Researchers who produce software should be cited for that work. Teachers who share their materials should be credited for easing the workloads of others. Those who provide pastoral care should be rewarded for taking on emotional burdens. Peer reviewers should be paid for sustaining the academic publishing system. Editors should have their labor recognized as research contributions. And so forth.

A variant of this reward structure is a system wherein all academics are expected to contribute evenly to a variety of "public goods". In essence, "everyone should do more service." But this kind of universalist argument misses the logic of comparative advantage: some academics are better at one thing than others and we should be incentivized to produce what we are best at so that we are collectively better off. It also seems slightly perverse to *require* people to *volunteer* - it's a contradiction in terms. 

Thus we are left in a world where it does not make sense for everyone to produce the same kinds of "public goods" but we have a system that only rewards certain certain kinds of goods production and otherwise relies upon a system of norms and mutual expectations to support essential goods like peer review and student supervision. Lacking a different rewards structure, all we have is a set of norms. The ease with which those norms are violated (or seen to be violated) breeds some of the widespread discontent with reward structures and compensation within academia.

Yet despite frustrations with the present state of things, any system meant to provide incentives to contribute "public goods" would most likely benefit those who generate physical goods (software, data, materials, formal mentoring schemes, etc.) while excluding those who generate equally or more important goods that cannot be easily recorded and shared. Said another way, though it might be easy to devise systems for rewarding *public* goods it would likely be quite difficult to devise systems for rewarding *private* goods that serve the public interest. Better incentivizing tangible public goods would likely exacerbate various academic inequalities by rewarding people with resources to produce them in the first place.

Of late, therefore, I have wondered whether this is the right way to understand the present system of "public goods" provision in academia. Goods provision based upon expectations of reciprocity or expectations of reward at all - in essence, that each individual contributes service to support the whole - tends to fail without some way of identifying all individuals in the community and then operating communication and enforcement mechanisms (see, for example, the work of [Elinor Ostrom](https://en.wikipedia.org/wiki/Elinor_Ostrom) on common pool resource management). Monitoring of performance and the provision of incentives are mostly the responsibility of individual academic institutions rather than collectives or communities - professional organizations lack the capacity or authority to serve such communication and enforcement roles.

Consequently, I have started to think about academic service (or "public goods" provision) not in terms of norms of reciprocity but instead in terms of a [*gift economy*](https://en.wikipedia.org/wiki/Gift_economy). In an academic gift economy, "public goods" are given away with no expectation of reward or reciprocity. They are not service to the profession or the community, but pure giveaways.

A gift economy is a closer approximation to the reality that we work in than a system of reciprocal contribution. Academics who generate software, build datasets, provide emotional labor, and so forth do so without a reasonable expectation of reward because no such reward really exists. Thanks from others is an intangible reward, but it doesn't carry the same academic career progression and salary rewards that accompany other kinds of contributions. Many public goods - like software - also don't have any obvious value other than money for time; for example, there's nothing I personally need professionally as much as research software so it's not something I can really trade for anything except for time building that same software. As such, I think that most of what I do in terms of "service" is actually a simple giveaway of my time. I cannot really be compensated for it and while I would like to be, I probably shouldn't expect it.

That sounds sort of romantic, but the reality is that in a gift economy, gift-giving is only possible by those with resources and inclination to give away without reward. In a gift economy, we should not expect others to contribute "public goods" because that expectation presumes the academic world operates according to reciprocity and incentivization of all labor. If we are a gift economy, we cannot expect others to contribute anything and we cannot be upset when they do not contribute. Acknowledging that we operate in a gift economy implicitly acknowledges that service reflects privileges of time, money, and other resources.

I'm not of the opinion that academia *ought* to necessarily operate as a gift economy, but I think it might be fruitful to think about the present system in those terms. Indeed, doing so would help to avoid the discontent about the unequal production of public goods. Thinking in these ways might also help to acknowledge challenges in devising more effective systems for monitoring effort spent on service. That task, I suspect, is particularly difficult because - if we accept that we are indeed a gift economy - any attempt to devise a reward system for the present production of service falsely assumes that gift production should be rewarded. That may not be the case. A better system of rewarding academic service and public goods production needs to instead start from a point of clarity about what kinds of service we actually need and how much we think each of those types of service is worth. We might find that we want to reward the kinds of service gifts that are currently generated. But we also might not. And we won't know until we sit down and really think about it.
